@@ -13,16 +13,16 @@ static const int CLONE_MAX_DEPTH = 5000;
 
 static MGVTBL clone_marker;
 
-static void _clone (SV* dest, SV* source, CloneMap* map, I32 depth);
+static void _clone (pTHX_ SV* dest, SV* source, CloneMap* map, I32 depth);
 
-SV* clone (SV* source, bool cross) {
+SV* clone (pTHX_ SV* source, bool cross) {
     SV* ret = newSV(0);
     try {
         if (cross) {
             CloneMap map;
-            _clone(ret, source, &map, 0);
+            _clone(aTHX_ ret, source, &map, 0);
         }
-        else _clone(ret, source, NULL, 0);
+        else _clone(aTHX_ ret, source, NULL, 0);
     } catch (int val) {
         SvREFCNT_dec(ret);
         croak("clone: max depth (%d) reached, it looks like you passed a cycled structure", CLONE_MAX_DEPTH);
@@ -30,7 +30,7 @@ SV* clone (SV* source, bool cross) {
     return ret;
 }
 
-static void _clone (SV* dest, SV* source, CloneMap* map, I32 depth) {
+static void _clone (pTHX_ SV* dest, SV* source, CloneMap* map, I32 depth) {
     if (depth > CLONE_MAX_DEPTH) throw 1;
 
     if (SvROK(source)) { // reference
@@ -83,7 +83,7 @@ static void _clone (SV* dest, SV* source, CloneMap* map, I32 depth) {
         SvROK_on(dest);
 
         if (is_object) sv_bless(dest, SvSTASH(source_val)); // cloning an object without any specific clone behavior
-        _clone(refval, source_val, map, depth+1);
+        _clone(aTHX_ refval, source_val, map, depth+1);
 
         return;
     }
@@ -119,7 +119,7 @@ static void _clone (SV* dest, SV* source, CloneMap* map, I32 depth) {
                 if (srcval != NULL) { // if not empty slot
                     SV* elem = newSV(0);
                     dstlist[i] = elem;
-                    _clone(elem, srcval, map, depth+1);
+                    _clone(aTHX_ elem, srcval, map, depth+1);
                 }
             }
             return;
@@ -136,7 +136,7 @@ static void _clone (SV* dest, SV* source, CloneMap* map, I32 depth) {
                     HEK* hek = HeKEY_hek(entry);
                     SV* elem = newSV(0);
                     hv_storehek((HV*)dest, hek, elem);
-                    _clone(elem, HeVAL(entry), map, depth+1);
+                    _clone(aTHX_ elem, HeVAL(entry), map, depth+1);
                 }
             }
 
